﻿var WordMod = {
    make: function () {
        var prefix = WordEnv.prefix;
        var root = document.querySelector(WordEnv.rootElem);
        var dictionaryCode = root.getAttribute('dicCode');
        var errorCode = root.getAttribute('errorCode');
        var gaijiDir = WordEnv.gaijiDir();
        var kanjiDir = WordEnv.kanjiDir();
        var kanjiFullDir = WordEnv.kanjiFullDir();
        var figureDir = WordEnv.figureDir();
        
        function appendWikiLink() {
            function accentsTidy(s) {
                var r = s.toLowerCase();
                r = r.replace(/[àáâãäå]/g, "a");
                r = r.replace(/æ/g, "ae");
                r = r.replace(/ç/g, "c");
                r = r.replace(/[èéêë]/g, "e");
                r = r.replace(/[ìíîï]/g, "i");
                r = r.replace(/ñ/g, "n");                
                r = r.replace(/[òóôõö]/g, "o");
                r = r.replace(/œ/g, "oe");
                r = r.replace(/[ùúûü]/g, "u");
                r = r.replace(/[ýÿ]/g, "y");
                r = r.replace(/・/g, "");
                return r;
            }
            var title;
            var mainHeader;
            var mainHeaderTitle;
            var mainHeaderRankStar;
            mainHeader = $(WordEnv.prefix('header.main'));
            mainHeaderTitle = $('h1', mainHeader);
            mainHeaderRankStarLen = $('.rank_star', mainHeaderTitle).text().length;
            mainHeaderSuperLen = $('sup', mainHeaderTitle).text().length;
            title = mainHeaderTitle.text();
            title = accentsTidy(title.substring(mainHeaderRankStarLen, title.length - mainHeaderSuperLen));
            mainHeader.append(
                '<a class="moreExamples external" href="http://en.wiktionary.org/wiki/' + title + '">例文</a>'
            );
        }

        WordEnv.preprocess();

        // Set root class
        root.setAttribute("class", dictionaryCode);

        // Insert dictionary title
        var header = document.createElement("header");
        header.setAttribute("class", "dic_title");
        header.innerText = WordEnv.dicTitle(dictionaryCode);
        if (root.firstChild) {
            root.insertBefore(header, root.firstChild);
        }

        // Append Wiktionary link to ej_dic
        if (dictionaryCode == 'ej_dic') {
            appendWikiLink();
        }

        // Bread crumbs navigation
        $('nav.crumbs a:not(:last-child)').each(function () {
            if (WordEnv.isScreenWideEnough()) {
                $(this).css('display', 'inline');
            }
            else {
                $(this).css('display', 'none');
            }
        });

        // gaiji
        $(prefix('img.gaiji')).each(function () {
            var gaiji = $(this).attr('src');
            if (gaiji.lastIndexOf('.png') == -1) {
                var srcPath = gaijiDir + gaiji + '.png';
                $(this).attr('src', srcPath);
            }
        });

        // kanji
        $(prefix('img.kanji')).each(function () {
            var gaiji = $(this).attr('src');
            if (gaiji.lastIndexOf('.png') == -1) {
                var srcPath = kanjiDir + gaiji + '.png';
                var popupPath = kanjiFullDir + gaiji + '.png';
                $(this).attr('src', srcPath);
                if ($(this).parent("a").size() == 0) {
                    $(this).bind('click', function () {
                        WordEnv.popupImage(popupPath, this);
                    });
                }
            }
        });

        // figure
        $(prefix('img.figure')).each(function () {
            var figure = $(this).attr('src');
            if (figure.lastIndexOf('.png') == -1) {
                var srcPath = figureDir + figure + '.png';
                $(this).attr('src', srcPath);
            }
        });
        
        // accordions
        var accordions = {
            '.kanji_dic section.radical_description': true,
            '.kanji_dic section.koji': false,
            '.ku_dic section.word': false,
            '.aw_dic section.menu.group': false,
            '.og100poem section.menu.group': false,
        };
        for (var s in accordions) {
            $(WordEnv.rootElem + s).each(function() {
                if (!$(this).hasClass('accordion')) {
                    function onClick() {
                        if (handle.hasClass('active')) {
                            handle.removeClass('active');
                            handle.text("＋");
                        }
                        else {
                            handle.addClass('active');
                            handle.text("ー");
                        }
                        target.slideToggle('fast');
                    }
                    $(this).addClass('accordion');
                    var handle = $(document.createElement('span'));
                    var title = $(this).children('h1:first');
                    var target = $(this).children(':last').addClass('accordion_target');
                    handle.addClass('accordion_handle');
                    if (accordions[s]) {
                        handle.addClass('active').text('ー');
                    }
                    else {
                        handle.text('＋');
                    }
                    $(this).children(':first').before(handle);
                    title.on('click', onClick);
                    handle.on('click', onClick);
                    if (!accordions[s]) {
                        target.hide();
                    }
                }
            });
        }

        // span ruby
        $(prefix('span.ruby')).each(function () {
            var oldValue = $(this).text();
            var newValue = " (" + oldValue.replace(/\uFF0F/g, "") + ") ";
            $(this).text(newValue);
        });

        // span reload
        $(prefix('span.reload')).bind('click', function () {
            WordEnv.reload();
        });

        // button stroke
        $(prefix('button.stroke')).each(function () {
            var gaiji = $(this).attr('value');
            var srcPath = kanjiDir + gaiji + '.png';
            var popupPath = kanjiFullDir + gaiji + '.png';
            $(this).bind('click', function () {
                WordEnv.popupVerticalScrollImage(popupPath, this);
            });
        });

        WordEnv.postprocess();
    },
    refreshGridListWidth: function () {
        function centering(node) {
            var W = node.parent().width();
            var li = node.find(">:first-child");
            var w = li.outerWidth();
            var h = li.outerHeight();
            var colNum = Math.floor(W / w);
            var num = node.children().size();
            var width = w * colNum;
            var height = h * Math.ceil(num / colNum);
            node.width(width).height(height);
        }
        var prefix = WordEnv.prefix;
        var fontsize_diff_ratio = 1.15;
        $(prefix('ul.grid.align_max')).each(function () {
            var W = 0;
            var li_list = $(this).children();
            li_list.each(function () {
                var w = $(this).width() * fontsize_diff_ratio;
                if (W < w) {
                    W = w;
                }
            });
            li_list.each(function () {
                $(this).width(W);
            });
        });
        $(prefix('ul.grid.chara')).each(function () {
            centering($(this));
        });
    }
};
